==========
Lino Prima
==========

School management software for primary schools.
Manage evaluation results, print certificates.

- Project homepage: https://gitlab.com/synodalsoft/prima
- Documentation: https://synodalsoft.gitlab.io/prima/
- Lino Developer Guide : https://dev.lino-framework.org
